@@ -283,7 +283,7 @@ sub vram_needed {
 
 # Returns truth according to virtualbox which can take the form of
 # null, Null, False, false (being 0) and True, true being 1
-sub bl { ($_[0] =~ m/^[t|T]/) // return 1 }
+sub bl { $_[0] =~ /^[tT]/ ? 1 : 0 }
 
 # Converts a path to its canonical form
 sub rcanonpath {
