@@ -259,7 +259,7 @@ sub fill_list_remotefiles {
     else {
         IVFSExplorer_cdUp($gui{IVFSExplorer}); # Failed to CD, so the path needs to be set back to the previous one
         $gui{d}{RemoteFileChooser}{entryLocation}->set_text(IVFSExplorer_getPath($gui{IVFSExplorer}));
-        show_err_msg('nodiraccess', '');
+        show_err_msg('nodiraccess', 0, '');
     }
 
     &set_pointer($gui{d}{RemoteFileChooser}{dialog});
@@ -1388,7 +1388,7 @@ sub onsel_list_shared {
         if (IMachine_getSnapshotCount($$gref{IMachine}) > 0) {
             my $ISnapshot_current = IMachine_getCurrentSnapshot($$gref{IMachine});
             my $ISnapshot = IMachine_findSnapshot($$gref{IMachine}, undef); # get first snapshot
-            &recurse_snapshot($ISnapshot, undef, $ISnapshot_current);
+            &recurse_snapshot($ISnapshot, undef, $ISnapshot_current, $$gref{IMachine});
             $gui{d}{Main}{treeviewSnap}->expand_all();
         }
 
@@ -1407,22 +1407,26 @@ sub onsel_list_shared {
     }
 
     sub recurse_snapshot {
-        my ($ISnapshot, $iter, $ISnapshot_current) = @_;
+        my ($ISnapshot, $iter, $ISnapshot_current, $IMachine) = @_;
         my $citer = $gui{d}{Main}{tstoreSnap}->append($iter);
         my $snapname = ISnapshot_getName($ISnapshot);
         my $date = scalar(localtime((ISnapshot_getTimeStamp($ISnapshot))/1000)); # VBox returns msecs so / 1000
-        $gui{d}{Main}{tstoreSnap}->set($citer, [0, 1, 2, 3], [$snapname,
+        $gui{d}{Main}{tstoreSnap}->set($citer, [0, 1, 2, 3, 4], [$snapname,
                                                              $date,
                                                              $ISnapshot,
-                                                             &bl(ISnapshot_getOnline($ISnapshot)) ? $gui{pb}{SnapshotOnline} : $gui{pb}{SnapshotOffline}]);
+                                                             &bl(ISnapshot_getOnline($ISnapshot)) ? $gui{pb}{SnapshotOnline} : $gui{pb}{SnapshotOffline},
+                                                             400]); # 400 , 700 is bold is pango int for normal text
 
         if ($ISnapshot eq $ISnapshot_current) {
             my $curiter = $gui{d}{Main}{tstoreSnap}->append($citer);
-            $gui{d}{Main}{tstoreSnap}->set($curiter, [0, 1, 2, 3], ['[Current State]', '', '', $gui{pb}{SnapshotCurrent}]);
+
+            if (&bl(IMachine_getCurrentStateModified($IMachine))) { $gui{d}{Main}{tstoreSnap}->set($curiter, [0, 1, 2, 3, 4], ['[Current State]  (changed)', '', '', $gui{pb}{SnapshotCurrent}, 700]); }
+            else { $gui{d}{Main}{tstoreSnap}->set($curiter, [0, 1, 2, 3, 4], ['[Current State]', '', '', $gui{pb}{SnapshotCurrent}, 380]); }
+
         }
 
         my @snapshots = ISnapshot_getChildren($ISnapshot);
-        if (@snapshots > 0) { &recurse_snapshot($_, $citer, $ISnapshot_current) foreach (@snapshots); }
+        if (@snapshots > 0) { &recurse_snapshot($_, $citer, $ISnapshot_current, $IMachine) foreach (@snapshots); }
     }
 }
 
@@ -1537,88 +1541,94 @@ sub onsel_list_shared {
         else {
             my $citer = $gui{d}{Main}{tstoreGuest}->append($piter);
             $gui{d}{Main}{tstoreGuest}->set($citer, [0, 6, 7], [$name, $gui{pb}{VMGroup}, $name]);
-            $$node{$name}{iter} = $citer;
-            $$node{$name}{node} = {};
+            $$node{$name} = { iter => $citer, node => {} };
             return $$node{$name}{node}, $citer;
         }
     }
 
-    # Populates the list of available guests
     sub fill_list_guest {
         my $osver = &osver();
         my %grouptree;
         &addrow_msg_log("Retrieving guest list from $endpoint");
         &set_pointer($gui{d}{Main}{win}, 'watch');
         &clr_list_guest();
-        my %guestlist;
         my @IMachine = IVirtualBox_getMachines($gui{websn});
         my $selection;
-        my $inaccessible = 0;
+        my %guestlist;
 
-        # Preprocess groups first, leads to a neater layout as groups will all be added to the treeview
-        # before the guests. Add iter to guestlist for use later to save us needing to look it up
-        foreach my $machine (@IMachine) {
-            my $node = \%grouptree; # Reset the tree to the start for each new guest
+        # Collate all the info we need, so we don't do more net calls than needed. Exclude inaccessib
+        foreach my $IMachine (@IMachine) {
+            if (&bl(IMachine_getAccessible($IMachine))) {
+                $guestlist{$IMachine} = {name   => IMachine_getName($IMachine),
+                                         groups => IMachine_getGroups($IMachine),  # Remove leading slash, using substitution without modifying in-place
+                                         uuid   => IMachine_getId($IMachine),
+                                         status => IMachine_getState($IMachine),
+                                         osid   => IMachine_getOSTypeId($IMachine)};
 
-            if (&bl(IMachine_getAccessible($machine))) {
-                $guestlist{$machine}{name} = IMachine_getName($machine);
-                my ($group) = IMachine_getGroups($machine); # We only care about the first group returned
-                $group =~ s/^\///; # Leading / is optional so always remove for simplicity
-                my @components = split('/', $group);
-                my $piter = undef;
-                ($node, $piter) = &add_guest_group($node, $_, $piter) foreach (@components);
-                $guestlist{$machine}{iter} = $piter;
+                $guestlist{$IMachine}{groups} =~ s/^\///;  # Leading / is optional, remove for simplicity
             }
-            else { $inaccessible = 1; }
+            else { &addrow_msg_log("WARNING: The guest $guestlist{$IMachine}{name} is inaccessible and has been excluded. Fix using vboxmanage or VirtualBox on the server."); }
         }
 
-        # Lets sort the guest list according to preference
-        my @machinelist;
+        # Order the IMachines by group, depending on preference
+        my @machine_sorted_group = $prefs{AUTOSORTGUESTLIST} ? sort { lc($guestlist{$a}{groups}) cmp lc($guestlist{$b}{groups}) } keys %guestlist : keys %guestlist;
+        # Order the IMachines by name, depending on preference
+        my @machine_sorted_name = $prefs{AUTOSORTGUESTLIST} ? sort { lc($guestlist{$a}{name}) cmp lc($guestlist{$b}{name}) } keys %guestlist : keys %guestlist;
 
-        if ($prefs{AUTOSORTGUESTLIST}) {
-            foreach my $m (sort { lc($guestlist{$a}{name}) cmp lc($guestlist{$b}{name}) } (keys %guestlist)) {
-                push(@machinelist, $m);
+        # We need to process the groups first, before adding any guests
+        foreach my $IMachine ( @machine_sorted_group  ) {
+            my $node = \%grouptree;
+            my @parts = split('/', $guestlist{$IMachine}{groups});
+            my $piter = undef;
+
+            foreach my $part (@parts) {
+                ($node, $piter) = &add_guest_group($node, $part, $piter);
             }
+
+            $guestlist{$IMachine}{iter} = $piter; # Associate the group iterator with the guest
         }
-        else { @machinelist = sort(keys %guestlist) };
 
-        foreach my $machine (@machinelist) {
-            my $ISnapshot = IMachine_getCurrentSnapshot($machine);
-            my $osid = IMachine_getOSTypeId($machine);
-            my $uuid = IMachine_getId($machine);
-            my $prettyname = $guestlist{$machine}{name};
-            my $status = IMachine_getState($machine);
-            if ($ISnapshot) { $prettyname .=  ' (' . ISnapshot_getName($ISnapshot) . ")\n$status"; }
-            else { $prettyname .=  "\n$status"; }
+        # Process and display each guest
+        foreach my $IMachine (@machine_sorted_name) {
+            my $uuid = $guestlist{$IMachine}{uuid};
+            my $status = $guestlist{$IMachine}{status};
+            my $ISnapshot = IMachine_getCurrentSnapshot($IMachine);
+            my $osid = $guestlist{$IMachine}{osid};
+            my $prettyname = $guestlist{$IMachine}{name};
 
-            my $iter = $gui{d}{Main}{tstoreGuest}->append($guestlist{$machine}{iter});
-            $gui{d}{Main}{tstoreGuest}->set($iter, [0, 1, 2, 3, 4, 5, 6, 7, 8], [$guestlist{$machine}{name},
-                                                                           $$osver{$osid}{description},
-                                                                           $machine,
-                                                                           $status,
-                                                                           $osid,
-                                                                           $uuid,
-                                                                           (-e "$gui{THUMBDIR}/$uuid.png") ? Gtk3::Gdk::Pixbuf->new_from_file("$gui{THUMBDIR}/$uuid.png") : $$osver{$osid}{icon},
-                                                                           $prettyname,
-                                                                           $gui{pb}{$status}]);
+            # Append snapshot name to prettyname if available (note, this is faster than a ternary version
+            if ($ISnapshot) { $prettyname .= ' (' . ISnapshot_getName($ISnapshot) . ")\n$status"; }
+            else { $prettyname .= "\n$status"; }
 
-            $gui{d}{Main}{treeviewGuest}->expand_all() if ($prefs{GUESTLISTEXPAND});
+            # Append to the guest list view
+            my $iter = $gui{d}{Main}{tstoreGuest}->append($guestlist{$IMachine}{iter});
+            $gui{d}{Main}{tstoreGuest}->set($iter, [0, 1, 2, 3, 4, 5, 6, 7, 8], [$guestlist{$IMachine}{name},
+                                                                                 $$osver{$osid}{description},
+                                                                                 $IMachine,
+                                                                                 $status,
+                                                                                 $osid,
+                                                                                 $uuid,
+                                                                                 (-e "$gui{THUMBDIR}/$uuid.png") ? Gtk3::Gdk::Pixbuf->new_from_file("$gui{THUMBDIR}/$uuid.png") : $$osver{$osid}{icon},
+                                                                                 $prettyname,
+                                                                                 $gui{pb}{$status}]);
+
+            $gui{d}{Main}{treeviewGuest}->expand_all() if $prefs{GUESTLISTEXPAND};
             $selection = $iter if ($uuid eq $selected{Uuid});
         }
 
+        # Select the previously selected guest if it exists
         if ($selection) {
             $gui{d}{Main}{treeviewGuest}->get_selection()->select_iter($selection);
             &onsel_list_guest();
         }
 
-        # Move the scrollbar to the position we were at before refreshing the list
+        # Restore scrollbar position
         $gui{d}{Main}{scrolledGuest}->get_vadjustment()->set_value($selected{vscrollbar_pos});
         &set_pointer($gui{d}{Main}{win});
         &addrow_msg_log("Retrieved guest list from $endpoint");
-        &addrow_msg_log('Warning: You have one or more guests that are inaccessible and have been excluded from ' .
-                        'the guest list. You must use vboxmanage or VirtualBox on the server to fix these issues') if ($inaccessible);
     }
 
+
     # Clear the guest list and snapshots
     sub clr_list_guest {
         # Record the vertical scrollbar position for restoring later
