@@ -159,12 +159,12 @@ sub show_dialog_connect {
             my $ver = IVirtualBox_getVersion($gui{websn});
 
             if (!$ver) {
-                &show_err_msg('connect', " ($url)");
+                &show_err_msg('connect', 0, " ($url)");
                 &virtualbox_logoff();
             }
             else {
                 &addrow_msg_log("Logged into $endpoint", "Running VirtualBox $ver");
-                &show_err_msg('vboxver', "Detected VirtualBox Version: $ver") if ($ver !~ m/^7.1/);
+                &show_err_msg('vboxver', $prefs{NOVERSIONWARNDIALOG}, "Detected VirtualBox Version: $ver") if ($ver !~ m/^7.1/);
                 my $vhost = &vhost();
 
                 if ($$vhost{vrdeextpack} =~ m/Oracle VirtualBox Extension Pack/i) { $gui{d}{Main}{buttonDisplay}->set_label('_Guest Display (RDP)'); }
@@ -174,7 +174,7 @@ sub show_dialog_connect {
                 }
                 else {
                     $gui{d}{Main}{buttonDisplay}->set_label('Guest Display Unavailable');
-                    &show_err_msg('noextensions');
+                    &show_err_msg('noextensions', $prefs{NOEXTPACKWARNDIALOG});
                 }
 
                 if ($prefs{ADDADDITIONS}) {
@@ -303,7 +303,7 @@ sub guest_log_save {
             close($guest_log_fh);
             &addrow_msg_log("Guest log $lognum for $$gref{Name}, saved to $filename");
         }
-        else { &show_err_msg('guestlogsave', "\nFile: $filename\nError: $!"); }
+        else { &show_err_msg('guestlogsave', 0, "\nFile: $filename\nError: $!"); }
     }
 }
 
@@ -327,7 +327,7 @@ sub save_msg_log {
             close($msg_log_fh);
             &addrow_msg_log("Saved the message log to: $filename");
         }
-        else { &show_err_msg('msglogsave', "\nFile: $filename\nError: $!"); }
+        else { &show_err_msg('msglogsave', 0, "\nFile: $filename\nError: $!"); }
     }
 }
 
@@ -349,7 +349,7 @@ sub show_dialog_exportappl {
         my $IStorageController = IMachine_getStorageControllerByName($$gref{IMachine}, $$attach{controller});
 
         if (IStorageController_getBus($IStorageController) eq 'USB') {
-            &show_err_msg('exportapplusb');
+            &show_err_msg('exportapplusb', 0);
             return;
         }
 
@@ -369,8 +369,8 @@ sub show_dialog_exportappl {
         my $response = $gui{d}{ExportAppl}{dialog}->run();
 
         if ($response eq 'ok') {
-            if (!$gui{d}{ExportAppl}{entryFile}->get_text()) { &show_err_msg('invalidfile'); }
-            elsif (!$gui{d}{ExportAppl}{entryName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{ExportAppl}{entryFile}->get_text()) { &show_err_msg('invalidfile', 0); }
+            elsif (!$gui{d}{ExportAppl}{entryName}->get_text()) { &show_err_msg('invalidname', 0); }
             else {
                 $gui{d}{ExportAppl}{dialog}->hide;
                 my $location = $gui{d}{ExportAppl}{entryFile}->get_text() . &getsel_combo($gui{d}{ExportAppl}{cboxFormat}, 2);
@@ -557,7 +557,7 @@ sub start_guest {
         if (IProgress_getCanceled($IProgress) eq 'true') { &addrow_msg_log("Starting guest $$gref{Name} cancelled"); }
         elsif ($resultcode != 0) {
             my $IVirtualBoxErrorInfo = IProgress_getErrorInfo($IProgress);
-            &show_err_msg('startguest', "Guest: $$gref{Name}\nCode: $resultcode\nError:\n" . IVirtualBoxErrorInfo_getText($IVirtualBoxErrorInfo));
+            &show_err_msg('startguest', 0, "Guest: $$gref{Name}\nCode: $resultcode\nError:\n" . IVirtualBoxErrorInfo_getText($IVirtualBoxErrorInfo));
         }
         else {
             $started = 1;
@@ -595,7 +595,7 @@ sub start_guest {
             }
         }
     }
-    else { &show_err_msg('sessionopen', " ($$gref{Name})"); }
+    else { &show_err_msg('sessionopen', 0, " ($$gref{Name})"); }
 
     ISession_unlockMachine($ISession) if (ISession_getState($ISession) ne 'Unlocked');
     &open_remote_display() if ($prefs{RDPAUTOOPEN} and $started);
@@ -641,7 +641,7 @@ sub restore_snapshot {
         &show_progress_window($IProgress, 'Restoring snapshot', $gui{pb}{ProgressSnapshotRestore});
         &addrow_msg_log("Restored snapshot of $$gref{Name}");
     }
-    else { &show_err_msg('restorefail', " ($$gref{Name})"); }
+    else { &show_err_msg('restorefail', 0, " ($$gref{Name})"); }
 
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
     &fill_list_guest(); # This also refreshes the snapshot list
@@ -655,7 +655,7 @@ sub delete_snapshot {
     if ($$sref{Lock} ne 'None') {
         my $snapref = &getsel_list_snapshots();
 
-        if (ISnapshot_getChildrenCount($$snapref{ISnapshot}) > 1) { &show_err_msg('snapdelchild', " ($$gref{Name})"); }
+        if (ISnapshot_getChildrenCount($$snapref{ISnapshot}) > 1) { &show_err_msg('snapdelchild', 0, " ($$gref{Name})"); }
         else { # Not cancellable
             my $snapuuid = ISnapshot_getId($$snapref{ISnapshot});
             my $IProgress = IMachine_deleteSnapshot($$sref{IMachine}, $snapuuid);
@@ -663,7 +663,7 @@ sub delete_snapshot {
             &addrow_msg_log("Deleted snapshot of $$gref{Name}");
         }
     }
-    else { &show_err_msg('snapdelete', " ($$gref{Name})"); }
+    else { &show_err_msg('snapdelete', 0, " ($$gref{Name})"); }
 
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
     &fill_list_guest(); # This also refreshes the snapshot list
@@ -681,7 +681,7 @@ sub take_snapshot {
         &show_progress_window($IProgress, 'Taking snapshot', $gui{pb}{ProgressSnapshotCreate}) if ($IProgress);
         &addrow_msg_log("Created snapshot of $$gref{Name} called $name");
     }
-    else { &show_err_msg('snapshotfail', " ($$gref{Name})"); }
+    else { &show_err_msg('snapshotfail', 0, " ($$gref{Name})"); }
 
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
     &fill_list_guest(); # This also refreshes the snapshot list
@@ -730,7 +730,7 @@ sub open_remote_display {
             &addrow_msg_log("Request sent to open the display of $$gref{Name} at address $dst:$$IVRDEServerInfo{port}", $dispcmd);
             system("$dispcmd");
         }
-        else { &show_err_msg('remotedisplay', " ($$gref{Name})"); }
+        else { &show_err_msg('remotedisplay', 0, " ($$gref{Name})"); }
     }
 
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
@@ -957,8 +957,8 @@ sub insert_removable_disk_first_drive {
         last;
     }
 
-    &show_err_msg('nodrive') if ($$medium{type} eq 'DVD' and !$found);
-    &show_err_msg('nofloppydrive') if ($$medium{type} eq 'Floppy' and !$found);
+    &show_err_msg('nodrive', 0) if ($$medium{type} eq 'DVD' and !$found);
+    &show_err_msg('nofloppydrive', 0) if ($$medium{type} eq 'Floppy' and !$found);
     IMachine_saveSettings($$sref{IMachine});
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
@@ -1191,7 +1191,7 @@ sub screenshot {
                 }
                 else { &addrow_msg_log("Warning: Failed to save screenshot of $$gref{Name} as $filename"); }
             }
-            else { &show_err_msg('noscreenshot'); }
+            else { &show_err_msg('noscreenshot', 0); }
         }
     }
 
@@ -1220,7 +1220,7 @@ sub screenshot_to_icon {
             }
             else { &addrow_msg_log("Warning: Could not save the icon for $$gref{Name}"); }
         }
-        else { &show_err_msg('noscreenshot'); }
+        else { &show_err_msg('noscreenshot', 0); }
     }
 
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
@@ -1253,7 +1253,7 @@ sub show_dialog_importappl {
             push (@importopts, 'KeepAllMACs') if ($gui{d}{ImportAppl}{cboxMAC}->get_active() == 0);
             push (@importopts, 'KeepNATMACs') if ($gui{d}{ImportAppl}{cboxMAC}->get_active() == 1);
 
-            if (!$gui{d}{ImportAppl}{entryAppl}->get_text()) { &show_err_msg('invalidfile'); }
+            if (!$gui{d}{ImportAppl}{entryAppl}->get_text()) { &show_err_msg('invalidfile', 0); }
             else {
                 $gui{d}{ImportAppl}{dialog}->hide();
                 my $appliancefile = $gui{d}{ImportAppl}{entryAppl}->get_text();
@@ -1278,9 +1278,9 @@ sub show_dialog_importappl {
                             &show_dialog_edit(); # Edit any settings
                         }
                     }
-                    else { &show_err_msg('applimport', "\nAppliance: $appliancefile"); }
+                    else { &show_err_msg('applimport', 0, "\nAppliance: $appliancefile"); }
                 }
-                else { &show_err_msg('applimport', "\nAppliance: $appliancefile"); }
+                else { &show_err_msg('applimport', 0, "\nAppliance: $appliancefile"); }
             }
         }
         else { $gui{d}{ImportAppl}{dialog}->hide; }
